.. _contribute:

**************************************
Contribute to TwoBody or report issues
**************************************

Contributions to the project are always welcome through pull requests on GitHub.
For significant proposed changes to the code, please start by opening an issue
on the `GitHub page for this project <https://github.com/adrn/twobody/issues>`_
describing your idea.  If it’s a bug fix or minor change to the source code, or
a change to the documentation, feel free to instead submit a pull request on
GitHub directly.

If you would like inspiration for things to work on, check out the
`feature-request issue label
<https://github.com/adrn/twobody/issues?q=is%3Aopen+is%3Aissue+label%3A%22feature+request%22>`_.
A few possible directions for future work pulled from there:

* Exoplanet transits, transit times, etc.
* Implement a way to get the time delay of a pulse from an orbiting body
* Interactions with a third body (acceleration) causing long-term trends in
  barycenter position and velocity

If you have other ideas for features that you would like to propose, please
create an issue on the `GitHub page for this project
<https://github.com/adrn/twobody/issues>`_.

If you’ve found a bug or issue with the code, or something that is unclear in
the documentation, please open an issue on the `GitHub page for this project
<https://github.com/adrn/twobody/issues>`_ describing the bug or issue.
